### 4.6.0-rc6 (13.11.2023)

- Upgrade `garpix_user` to version 3.10.0-rc4

### 4.6.0-rc5 (13.11.2023)

- Upgrade `garpix_user` to version 3.10.0-rc3

### 4.6.0-rc4 (08.11.2023)

- Upgrade `garpix_user` to version 3.10.0-rc2

### 4.6.0-rc2-4.6.0-rc3 (07.11.2023)

- Upgrade `garpix_utils` to version 1.9.1

### 4.6.0-rc1 (07.11.2023)

- Upgrade `garpix_user` to version 3.10.0-rc1

### 4.5.2 (19.09.2023)

- Upgrade `garpix_page` to version 2.48.2
- Upgrade `garpix_notify` to version 5.16.2.

### 4.5.1 (29.08.2023)

- Upgrade `garpix_user` to version 3.9.1

### 4.5.0 (14.07.2023)

- Upgrade `garpix_utils` to version 1.9.0
- Upgrade `garpix_user` to version 3.9.0
- Upgrade `garpix_page` to version 2.48.1

### 4.5.0-rc3 (03.07.2023)

- Upgrade `garpix_utils` to version 1.9.0-rc3

### 4.5.0-rc2 (03.07.2023)

- Upgrade `garpix_utils` to version 1.9.0-rc2

### 4.5.0-rc1 (26.06.2023)

- Upgrade `garpix_utils` to version 1.9.0-rc1

### 4.4.1 (26.06.2023)

- Upgrade `garpix_user` to version 3.8.1

### 4.4.0 (23.06.2023)

- Upgrade `garpix_user` to version 3.8.0
- `django.contrib.auth.backends.ModelBackend` deprecated

### 4.3.1 (09.06.2023)

- Upgrade `garpix_user` to version 3.6.1

### 4.3.0 (31.05.2023)

- Upgrade `garpix_page` to version 2.48.0
- Upgrade `garpix_user` to version 3.6.0
- Update documentation

### 4.2.0 (29.05.2023)

- Upgrade `garpix_page` to version 2.47.0

### 4.1.1 (12.05.2023)

- Upgrade `garpix_page` to version 2.46.1

### 4.1.0 (12.05.2023)

- Upgrade `garpix_page` to version 2.46.0

### 4.0.0 (10.05.2023)

- Upgrade `garpix_user` to version 3.5.0
- Upgrade `garpix_page` to version 2.45.0
- Upgrade `garpix_notify` to version 5.16.0.

### 4.0.0-rc20 (28.04.2023)

- Upgrade `garpix_page` to version 2.45.0-rc10.
- Upgrade `garpix_menu` to version 1.16.0.


### 4.0.0-rc18-4.0.0-rc19 (25.04.2023)

- Upgrade `garpix_page` to version 2.45.0-rc9.
- Upgrade `garpix_notify` to version 5.15.1.

### 4.0.0-rc17 (19.04.2023)

- Upgrade `garpix_user` to version 3.5.0-rc8.

### 4.0.0-rc16 (18.04.2023)

- Upgrade `garpix_user` to version 3.5.0-rc7.

### 4.0.0-rc15 (14.04.2023)

- Upgrade `garpix_page` to version 2.45.0-rc8.
- Upgrade `garpix_notify` to version 5.15.0.
- Upgrade `garpix_user` to version 3.5.0-rc6.

### 4.0.0-rc14 (06.04.2023)

- Upgrade `eqator` to version 2.7.0.

### 4.0.0-rc13 (30.03.2023)

- Upgrade `garpix_page` to version 2.45.0-rc7.

### 4.0.0-rc8-4.0.0-rc12 (24.03.2023)

- Upgrade `garpix_page` to version 2.45.0-rc6.

### 4.0.0-rc7 (24.03.2023)

- Upgrade `garpix_page` to version 2.45.0-rc1.
- Upgrade `garpix_menu` to version 1.15.0.
- Upgrade `garpix_notify` to version 5.14.0.

### 4.0.0-rc6 (20.03.2023)

- Upgrade `garpix_user` to version 3.5.0-rc5.

### 4.0.0-rc5 (15.03.2023)

- Upgrade `garpix_user` to version 3.5.0-rc3.

### 4.0.0-rc4 (13.03.2023)

- Upgrade `garpix_page` to version 2.44.0.

### 4.0.0-rc1-4.0.0-rc3 (07.03.2023)

- `garpx_auth` replaced by `garpix_user` (see https://garpixcms.github.io/garpixcms/ for detailed info)
- Upgrade `garpix_page` to version 2.43.0.

### 3.54.0-rc1-3.54.0-rc2 (28.02.2023)

- New admin styles

### 3.53.0-3.53.1 (28.02.2023)

- Upgrade `garpix_page` to version 2.42.0.
- Upgrade `garpix_menu` to version 1.14.0.

### 3.53.0-rc4 (24.02.2023)

- Upgrade `garpix_page` to version 2.42.0-rc3.

### 3.53.0-rc3 (10.02.2023)

- Upgrade `garpix_menu` to version 1.14.0-rc1.
- Update documentation.
- Update `global_context` menus structure (one array nesting was deprecated).

### 3.53.0-rc2 (09.02.2023)

- Upgrade `garpix_page` to version 2.42.0-rc2.

### 3.53.0-rc1 (08.02.2023)

- Upgrade `garpix_page` to version 2.42.0-rc1.

### 3.52.0 (01.02.2023)

- Upgrade `garpix_page` to version 2.41.0.
- Upgrade `garpix_utils` to version 1.8.0.

### 3.51.0 (09.12.2022)

- Upgrade `garpix_page` to version 2.40.1.

### 3.50.0 (30.11.2022)

- Upgrade `garpix_notify` to version 5.13.6.
- Upgrade `garpix_utils` to version 1.7.0.
- `ENABLE_SWAGGER` setting added.

### 3.49.1 (28.11.2022)

- Исправлена ошибка `AttributeError: 'URLResolver' object has no attribute '_extend_tried'` для `django==3.1`.

### 3.49.0 (24.11.2022)

- Upgrade `garpix_page` to version 2.40.0.
- Upgrade `garpix_notify` to version 5.13.5.

### 3.48.0 - 3.48.2 (17.11.2022)

- Upgrade `garpix_page` to version 2.39.1.

### 3.47.0 (16.11.2022)

- Upgrade `garpix_menu` to version 1.13.0.
- Upgrade `garpix_notify` to version 5.13.4.
- `GarpixLocaleMiddleware` added.

### 3.46.0 (02.11.2022)

- Upgrade `garpix_menu` to version 1.12.1.
- `global_context` fixed (menu serialized for drf).

### 3.45.0 (02.11.2022)

- Upgrade `garpix_page` to version 2.39.0.
- Upgrade `garpix_admin_lock` to version 1.1.0.

### 3.44.0 (25.10.2022)

- Upgrade `garpix_page` to version 2.38.0.
- Upgrade `garpix_notify` to version 5.13.3.
- Upgrade `eqator` to version 2.6.0.

### 3.44.0-rc6 (20.10.2022)

- Upgrade `garpix_page` to version 2.38.0-rc7.

### 3.44.0-rc5 (14.10.2022)

- Upgrade `garpix_page` to version 2.38.0-rc6.

### 3.44.0-rc4 (14.10.2022)

- Upgrade `garpix_page` to version 2.38.0-rc5.

### 3.44.0-rc3 (12.10.2022)

- Upgrade `garpix_page` to version 2.38.0-rc4.

### 3.44.0-rc2 (12.10.2022)

- Upgrade `garpix_page` to version 2.38.0-rc3.

### 3.44.0-rc1 (10.10.2022)

- Upgrade `garpix_page` to version 2.38.0-rc1.

### 3.43.0 (10.10.2022)

- Upgrade `garpix_notify` to version 5.13.2.

### 3.42.0 (07.10.2022)

- Upgrade `garpix_page` to version 2.37.0.
- Upgrade `garpix_utils` to version 1.6.0.

### 3.41.0 (06.10.2022)

- Upgrade `garpix_page` to version 2.36.1.
- Upgrade `garpix_notify` to version 5.13.1.

### 3.40.0 (30.09.2022)

- Upgrade `garpix_page` to version 2.36.0.
- Upgrade `eqator` to version 2.5.0.

### 3.39.0 (29.09.2022)

- Upgrade `garpix_notify` to version 5.12.5.
- Upgrade `garpix_menu` to version 1.11.0.

### 3.38.0 (27.09.2022)

- Upgrade `garpix_notify` to version 5.12.4.

### 3.37.0 (26.09.2022)

- Upgrade `garpix_utils` to version 1.5.1.
- Upgrade `garpix_notify` to version 5.12.3.
- Upgrade `eqator` to version 2.4.1.

### 3.36.1 (23.09.2022)

- Fixed upgrade `garpix_notify` to version 5.11.6 in setup.py.

### 3.36.0 (23.09.2022)

- Upgrade `garpix_notify` to version 5.11.6.

### 3.35.1 (21.09.2022)

- Add `garpix_admin_lock` settings to `settings.py` file.  

### 3.35.0 (21.09.2022)

- Upgrade `garpix_page` to version 2.35.0.
- Upgrade `garpix_notify` to version 5.11.5.
- Upgrade `eqator` to version 2.4.0.

### 3.34.0 (02.09.2022)

- Upgrade `garpix_page` to version 2.34.0.

### 3.33.0 (01.09.2022)

- Upgrade `garpix_page` to version 2.33.1.

### 3.32.0 (01.09.2022)

- Upgrade `garpix_page` to version 2.33.0.

### 3.31.0 (29.08.2022)

- Upgrade `garpix_page` to version 2.31.0.
- Upgrade `equator` to version 2.3.0.

### 3.29.0 (24.08.2022)

- Upgrade `garpix_notify` to version 5.11.2.

### 3.27.0 (22.08.2022)

- Upgrade `garpix_notify` to version 5.11.1.

### 3.26.0 (18.08.2022)

- Upgrade `garpix_page` to version 2.28.1.

### 3.25.0 (17.08.2022)

- Upgrade `equator` to version 2.1.2.

### 3.24.0 (16.08.2022)

- Upgrade `garpix_page` to version 2.28.0.
- Upgrade `garpix_menu` to version 1.10.0.
- Remove `garpix_qa`.
- Add `equator` version 2.1.1.

### 3.24.0-rc4 (25.07.2022)

- Upgrade `garpix_page` to version 2.27.1

### 3.24.0-rc3 (25.07.2022)

- Upgrade `garpix_page` to version 2.27.0.

### 3.24.0-rc1, 3.24.0-rc2 (15.07.2022)

- Upgrade `garpix_page` to version 2.26.0.

### 3.23.0 (13.07.2022)

- Теперь garpixcms позволяет использовать в проекте django версии от 3.1 до 4 (в предыдущей версии была строго задана 3.2).

### 3.22.0 (30.06.2022)

- Upgrade `garpix_notify` to version 5.9.0.
- Upgrade `garpix_page` to version 2.25.0.
- Upgrade `garpix_menu` to version 1.9.0.
- Upgrade `garpix_utils` to version 1.5.0.
- Upgrade `garpix_qa` to version 1.10.0.

### 3.21.0 (01.06.2022)

- Upgrade `garpix_notify` to version 5.7.0.

### 3.20.0 (30.05.2022)

- Upgrade `garpix_notify` to version 5.6.2.

### 3.19.0 (19.05.2022)

- Upgrade `garpix_notify` to version 5.6.1.

### 3.18.0 (12.05.2022)

- Upgrade `garpix_qa` to version 1.9.0.
- Upgrade `garpix_page` to version 2.24.0.
- Upgrade `garpix_notify` to version 5.4.2.

### 3.17.0 (04.05.2022)

- Upgrade `garpix_page` to version 2.23.0.
- Upgrade `garpix_qa` to version 1.8.0.

### 3.16.0 (22.04.2022)

- Upgrade `garpix_page` to version 2.22.0.
- Upgrade `garpix_menu` to version 1.8.0.
- Upgrade `garpix_qa` to version 1.7.0.

### 3.15.0-3.15.1 (15.04.2022)

- Upgrade `garpix_page` to version 2.21.0.
- Pinned `django-ckeditor == 6.3.0`.

### 3.14.0 (12.04.2022)

- Upgrade `garpix_page` to version 2.20.0.

### 3.13.0 (04.04.2022)

- Upgrade `garpix_notify` to version 5.4.1.

### 3.12.0 (01.04.2022)

- Upgrade `garpix_notify` to version 5.4.0.

### 3.11.0 (18.03.2022)

- Upgrade `garpix_page` to version 2.19.0.

### 3.10.0 (17.03.2022)

- Upgrade `garpix_page` to version 2.18.0.
- Upgrade `garpix_notify` to version 5.3.3.

### 3.9.0 (22.02.2022)

- Upgrade `garpix_page` to version 2.17.0.
- Upgrade `garpix_notify` to version 5.3.2.

### 3.8.0 (18.02.2022)

- Upgrade `garpix_page` to version 2.16.0.

### 3.7.0 (17.02.2022)

- LocaleMiddleware added to settings.
- Upgrade `garpix_page` to version 2.15.0.

### 3.6.0 (16.02.2022)

- Upgrade `garpix_page` to version 2.14.0.

### 3.5.0 (15.02.2022)

- Fixed upgrade `garpix_page` to version 2.13.0 in setup.py.
- Fixed upgrade `garpix_notify` to version 5.3.0 in setup.py.
- Upgrade `garpix_qa` to version 1.6.0.

### 3.4.1 (09.02.2022)

- Fixed upgrade `garpix_qa` to version 1.5.0 in setup.py.

### 3.4.0 (02.02.2022)

- Upgrade `garpix_qa` to version 1.5.0.
- Upgrade `garpix_page` to version 2.13.0.
- Upgrade `garpix_notify` to version 5.3.0.
- Added `Makefile`.
- Added pre commit hooks.

### 3.3.0 (13.01.2022)

- Upgrade `garpix_qa` to version 1.3.0.

### 3.2.0 (13.01.2022)

- Added `sentry`. See `SENTRY_DSN_STRING` in `.env`.

### 3.1.0 (12.01.2022)

- Upgrade `garpix_menu` to version 1.7.0.

### 3.0.0 (11.01.2022)

- Upgrade `garpix_notify` to version 5.1.2.

### 2.22.0 (15.12.2021)

- Upgrade `garpix_package` to version 2.0.1.

### 2.21.0 (08.11.2021)

- Upgrade `garpix_menu` to version 1.6.2.

### 2.20.0 (08.11.2021)

- Upgrade `garpix_menu` to version 1.6.1.

### 2.19.0 (08.11.2021)

- Add social urls.

### 2.19.0 (18.10.2021)

- Upgrade `garpix_menu` to version 1.6.0.

### 2.18.0 (18.10.2021)

- Upgrade `garpix_auth` to version 2.3.0.

### 2.17.0 (08.10.2021)

- Upgrade `garpix_auth` to version 2.2.0.

### 2.16.0 (26.09.2021)

- Upgrade `garpix_page` to version 2.12.0.

### 2.15.0 (25.09.2021)

- Upgrade `garpix_page` to version 2.11.0.

### 2.14.0 (21.09.2021)

- Upgrade `garpix_auth` to version 2.1.0.

### 2.13.0 (19.09.2021)

- Upgrade `garpix_menu` to version 1.5.1.

### 2.12.0 (19.09.2021)

- Upgrade `garpix_menu` to version 1.5.0.

### 2.11.0 (19.09.2021)

- Upgrade `garpix_menu` to version 1.4.0.

### 2.10.0 (19.09.2021)

- Added global context for api pages.
- Upgrade `garpix_menu` to version 1.3.0.

### 2.9.0 (19.09.2021)

- Added endpoint `{API_URL}/page/{page_slug}` for SPA sites.

### 2.8.1 (18.09.2021)

- Added to INSTALLED_APPS 'django.contrib.sitemaps'.

### 2.8.0 (18.09.2021)

- Upgrade `garpix_menu` to version 1.2.0.

### 2.7.0 (15.09.2021)

- Added settings.py variable `API_URL` (defaults to `api`).

### 2.6.0 (14.09.2021)

- Upgrade `garpix_page` to version 2.9.0.
- Upgrade `garpix_qa` to version 1.2.0.

### 2.5.0 (10.09.2021)

- Upgrade `garpix_auth` to version 2.0.2.

### 2.4.0 (10.09.2021)

- Upgrade `garpix_page` to version 2.8.0.

### 2.3.0 (09.09.2021)

- Upgrade `garpix_page` to version 2.7.0.

### 2.2.1 (08.09.2021)

- Hotfix: Added `garpix_utils` to INSTALLED_APPS.

### 2.2.0 (08.09.2021)

- Upgrade `garpix_utils` to version 1.3.0.
- Upgrade `garpix_page` to version 2.6.0.
- Upgrade `garpix_menu` to version 1.1.0.
- Changed `drf_yasg` to `drf_spectacular`.

### 2.1.0 (02.09.2021)

- Upgrade `garpix_notify` to version 4.1.0.

### 2.0.4 (02.09.2021)

- Upgrade `garpix_notify` to version 4.0.2.

### 2.0.3 (27.08.2021)

- Upgrade `garpix_notify` to version 4.0.1.

### 2.0.1-2.0.2 (19.08.2021)

- Hot fixes.

### 2.0.0 (19.08.2021)

- Upgrade `garpix_auth` to version 2.0.1.

### 1.15.0 (12.08.2021)

- Upgrade `garpix_notify` to version 4.0.0.

### 1.14.0 (08.08.2021)

- Upgrade `garpix_pack` to `garpix_package` version 2.0.0.

### 1.13.0 (06.08.2021)

- Upgrade `garpix_page` to version 2.5.0.

### 1.12.0 (29.07.2021)

- Upgrade `garpix_page` to version 2.4.0.

### 1.11.0 (29.07.2021)

- Upgrade `garpix_page` to version 2.3.0.

### 1.10.0 (29.07.2021)

- Added static urls to urlpatterns.

### 1.9.2 (27.07.2021)

- Upgrade `garpix_utils` to version 1.1.0.

### 1.9.1 (21.07.2021)

- Upgrade `garpix_utils` to version 1.0.2.

### 1.9.0 (21.07.2021)

- Added package `garpix_utils`.

### 1.8.1 (20.07.2021)

- Upgrade `garpix_menu` to version 1.0.2.

### 1.8.0 (19.07.2021)

- Url for login `token-auth/` changed to `api/login/`.

### 1.7.3 (19.07.2021)

- `ENABLE_GARPIX_AUTH` now is bool environment variable. Fixed bug with `reverse url authorize`.

### 1.7.2 (19.07.2021)

- Added `/frontend/templates` to `TEMPLATES` variable. 

### 1.7.1 (18.07.2021)

- From version 1.7.0 `pack` and `startpackage` into package `garpix_pack`.

### 1.7.0 (18.07.2021)

- Added manage.py command `pack` for packing packages. Syntax use - `python3 manage.py pack <app_name>`

### 1.6.4 (17.07.2021)

- Upgrade `garpix_menu` to version 1.0.1.

### 1.6.3 (12.07.2021)

- Upgrade `garpix_notify` to version 3.0.3.

### 1.6.2 (11.07.2021)

- Path for `.env` file.

### 1.6.1 (08.07.2021)

- Resort `INSTALLED_APPS`.

### 1.6.0 (08.07.2021)

- Added `django-cors-headers`. If `DEBUG == True`, then `CORS_ALLOW_ALL_ORIGINS = True`

### 1.5.2 (03.07.2021)

- Upgrade `garpix_qa` to version 1.0.6.

### 1.5.1 (01.07.2021)

- Changed `/static/` to `/static-backend/`.

### 1.5.0 (01.07.2021)

- Upgrade `garpix_notify` to version 3.0.2.

### 1.4.3 (01.07.2021)

- Added documentation to url: `/api/docs/`

### 1.4.2 (29.06.2021)

- Bug fix with `BASE_DIR` for `garpix_qa`.

### 1.4.1 (28.06.2021)

- Bug fix with `garpix_notify` - url not resolved `authorize`.

### 1.4.0 (28.06.2021)

- Added `garpix_notify`.

### 1.3.1 (24.06.2021)

- Fix templates, docs.

### 1.3.0 (24.06.2021)

- Added `garpix_auth`.

### 1.2.0 (23.06.2021)

- Upgrade `garpix_page` to version 2.2.0.

### 1.1.0 (22.06.2021)

- Upgrade `garpix_page` to version 2.0.0.

### 1.0.3 (12.05.2021)

- Bug fix with djangorestframework dependency.

### 1.0.2 (12.05.2021)

- Bug fix with CKEditor dependency.

### 1.0.0-1.0.1 (11.05.2021)

- Release on pypi.org.
